searchNodes=[{"doc":"Local time support for Nerves devices The nerves_time_zones application provides support for local time on Nerves devices. It does this by bundling a time zone database that's compatible with the zoneinfo library and providing logic to set the local time zone with the C runtime (and hence Erlang and Elixir). To use, call NervesTimeZones.set_time_zone/1 with the any IANA time zone name (e.g., &quot;America/New_York&quot; ). The time zone will be persisted so you won't need to set it again. It is safe to always set it on boot if your project will always be located in one time zone. After this, calls to NaiveDateTime.local_now/1 will return the local time. If you would prefer DateTime struct, call DateTime.now(NervesTimeZones.get_time_zone()) . If running a non-BEAM program that is time zone aware, you may need to set environment variables for it to work right. See NervesTimeZones.tz_environment/0 for the proper settings.","ref":"NervesTimeZones.html","title":"NervesTimeZones","type":"module"},{"doc":"Return the current local time zone","ref":"NervesTimeZones.html#get_time_zone/0","title":"NervesTimeZones.get_time_zone/0","type":"function"},{"doc":"Reset the time zone to the default This cleans up any saved time zone information and reapplies the defaults. The default time zone is &quot;Etc/UTC&quot;, but this can be changed by adding something like the following to your config.exs : config :nerves_time_zones , default_time_zone : &quot;Asia/Tokyo&quot;","ref":"NervesTimeZones.html#reset_time_zone/0","title":"NervesTimeZones.reset_time_zone/0","type":"function"},{"doc":"Set the local time zone Only known time zone names can be set. Others will return an error. &quot;Etc/UTC&quot; should always be available. This time zone will be persisted and restored after a reboot.","ref":"NervesTimeZones.html#set_time_zone/1","title":"NervesTimeZones.set_time_zone/1","type":"function"},{"doc":"Return all known time zones This function scans the time zone database each time it's called. It's not slow, but if you just need to verify whether a time zone exists, call valid_time_zone?/1 instead.","ref":"NervesTimeZones.html#time_zones/0","title":"NervesTimeZones.time_zones/0","type":"function"},{"doc":"Return environment variables for running OS processes If you're using System.cmd/3 to start an OS process that is time zone aware, call this to set the environment appropriately. For example, System.cmd(&quot;my_program&quot;, [], env: NervesTimeZones.tz_environment())","ref":"NervesTimeZones.html#tz_environment/0","title":"NervesTimeZones.tz_environment/0","type":"function"},{"doc":"Return whether a time zone is valid","ref":"NervesTimeZones.html#valid_time_zone?/1","title":"NervesTimeZones.valid_time_zone?/1","type":"function"},{"doc":"NervesTimeZones Local time and time zones for Nerves devices NervesTimeZones provides a way of managing local time on embedded devices. It provides the following: Set your time zone and have it be used for local time calls like NaiveDateTime.local_now/0 . The time zone persists across reboots. Set up Elixir's Calendar time zone database using zoneinfo Provide a small time zone database appropriate for many embedded devices It does not support the automatic update of the time zone database like tzdata and tz . For now, you'll need to watch for new versions of the nerves_time_zones package. (We're open to changing this, but it's not as easy as regularly polling IANA.) The primary motivation for creating this library was to reduce the size of the time zone database. tzdata and tz both work by compiling the IANA database to an internal format. At the time, tzdata compiled to a 3.5 MB ets table (~600 KB gzip compressed) and tz compiled to a 300 KB beam file (~250 KB gzip compressed). Using TZif files (the /usr/share/zoneinfo ones) and 10 years of time zone records for all time zones resulted in about 450 KB of data (~16 KB gzip compressed).","ref":"readme.html","title":"NervesTimeZones","type":"extras"},{"doc":"First, add nerves_time_zones to your list of dependencies in mix.exs : def deps do [ { :nerves_time_zones , &quot;~&gt; 0.1.2&quot; } ] end NervesTimeZones persists the currently selected local time zone to &quot;/data/nerves_time_zones&quot; . This works well on Nerves devices. If you're developing on your laptop, you may want to change the location by adding the following in your project's config.exs : config :nerves_time_zones , data_dir : &quot;./tmp/nerves_time_zones&quot; The default time zone is &quot;Etc/UTC&quot;. If you want it to be something else, set it in the config like this: config :nerves_time_zones , default_time_zone : &quot;Europe/Paris&quot;","ref":"readme.html#installation","title":"NervesTimeZones - Installation","type":"extras"},{"doc":"If you just start up IEx, you may have seen something like this: iex&gt; DateTime . now ( &quot;America/New_York&quot; ) { :error , :utc_only_time_zone_database } NervesTimeZones automatically sets up the time zone database so once you've added the :nerves_time_zones dependency, you'll get this instead: iex&gt; DateTime . now ( &quot;America/New_York&quot; ) { :ok , # DateTime &lt; 2021 - 03 - 11 10 : 19 : 59.811175 - 05 : 00 EST America / New_York &gt; } NervesTimeZones is opinionated on the time zone database provider so it forces the default and will log messages if there's a conflict with tzdata or tz . You can still use those time zone databases if you really want them even though it defeats the purpose of keeping one database on a device. You'll just need to manually specify the database in all of your DateTime calls.","ref":"readme.html#database-example","title":"NervesTimeZones - Database example","type":"extras"},{"doc":"By default with NervesTimeZones , local time will be UTC. You can see this by running NaiveDateTime.local_now/1 . Be aware that this behavior is different from the normal behavior of using your system's local time zone setting if you trying this out on your laptop. Nerves devices don't have time zone settings by default. iex&gt; DateTime . utc_now ~U[2021-03-11 15:10:41.573579Z] iex&gt; NaiveDateTime . local_now ~N[2021-03-11 15:10:44] You can set the time zone like this (note the time shift by 5 hours): iex&gt; NervesTimeZones . set_time_zone ( &quot;America/New_York&quot; ) :ok iex&gt; NaiveDateTime . local_now ~N[2021-03-11 10:11:02]","ref":"readme.html#local-time-example","title":"NervesTimeZones - Local time example","type":"extras"},{"doc":"It's possible to use the same time zone database with non-BEAM programs. For example, on my system the default for C programs is Eastern time: iex&gt; System . cmd ( &quot;date&quot; , [ ] ) { &quot;Thu 11 Mar 2021 10:34:14 AM EST \\n &quot; , 0 } On a Nerves device, this would be UTC, but the concept is the same. Say I want it to be Hawaii time: iex&gt; NervesTimeZones . set_time_zone ( &quot;Pacific/Honolulu&quot; ) :ok This won't affect the date program since it's not running on the BEAM. All is not lost. NervesTimeZones can provide environment settings so that the C runtime will use the same data base and time zone setting as on the BEAM: iex&gt; System . cmd ( &quot;date&quot; , [ ] , env : NervesTimeZones . tz_environment ( ) ) { &quot;Thu 11 Mar 2021 05:40:38 AM HST \\n &quot; , 0 } iex ) &gt; NaiveDateTime . local_now ~N[2021-03-11 05:40:49]","ref":"readme.html#running-os-commands","title":"NervesTimeZones - Running OS commands","type":"extras"},{"doc":"NervesTimeZones pulls data from the IANA time zone database and compiles it to TZif files using zic(8) . This is the same process used to create the files under /usr/share/zoneinfo . The difference is that those contain time period records 50 years or more in the past and over 15 years to the future. NervesTimeZones limits the range substantially to reduce the database size. Since the main embedded use cases for time zone information are to show the time and schedule events in the local time, having past time zone information is not needed. This saves a ton of space, since time zones changed a lot in the 20th century. The second part of the library is a NIF that updates the C runtime's local time zone setting. This setting also affects Erlang's and Elixir's local time functions like NaiveDateTime.local_now/0 as well. The NIF is trivially short and calls tzset(3) with the TZif file. Unfortunately, the way to pass the time zone is via the TZ environment variable, so if TZ previously pointed to anything before this library runs, it won't afterwards.","ref":"readme.html#how-it-works","title":"NervesTimeZones - How it works","type":"extras"},{"doc":"Copyright (C) 2021 Frank Hunleth Licensed under the Apache License , Version 2.0 ( the &quot;License&quot; ) ; you may not use this file except in compliance with the License . You may obtain a copy of the License at [ http :/ / www . apache . org / licenses / LICENSE - 2.0 ] ( http :/ / www . apache . org / licenses / LICENSE - 2.0 ) Unless required by applicable law or agreed to in writing , software distributed under the License is distributed on an &quot;AS IS&quot; BASIS , WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND , either express or implied . See the License for the specific language governing permissions and limitations under the License .","ref":"readme.html#license","title":"NervesTimeZones - License","type":"extras"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Updates Update the IANA database to 2021c (reverts the time zone removals in 2021b)","ref":"changelog.html#v0-1-8","title":"Changelog - v0.1.8","type":"extras"},{"doc":"Updates Update the IANA database to 2021b","ref":"changelog.html#v0-1-7","title":"Changelog - v0.1.7","type":"extras"},{"doc":"Improvements Switch from wget to curl for database download to be friendlier to MacOS users Cleanup and reduce Makefile prints","ref":"changelog.html#v0-1-6","title":"Changelog - v0.1.6","type":"extras"},{"doc":"Bug fixes Fix Makefile to support cross-compilation on Mac.","ref":"changelog.html#v0-1-5","title":"Changelog - v0.1.5","type":"extras"},{"doc":"Bug fixes Setting the default timezone didn't work on Nerves. Thanks to @pojiro for fixing this.","ref":"changelog.html#v0-1-4","title":"Changelog - v0.1.4","type":"extras"},{"doc":"Updates Update the IANA database to 2021a Add GitHub action to check for IANA database updates and automatically send a PR. Thanks to Connor Rigby for huge time saver.","ref":"changelog.html#v0-1-3","title":"Changelog - v0.1.3","type":"extras"},{"doc":"New features Support changing the default time zone to something besides &quot;Etc/UTC&quot;","ref":"changelog.html#v0-1-2","title":"Changelog - v0.1.2","type":"extras"},{"doc":"Bug fixes Add files that were missing from the hex package","ref":"changelog.html#v0-1-1","title":"Changelog - v0.1.1","type":"extras"},{"doc":"Initial release to hex.","ref":"changelog.html#v0-1-0","title":"Changelog - v0.1.0","type":"extras"}]